@@ -1,8 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
-#
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,7 +16,7 @@
 """Access Control Lists (ACL's) control access the API server."""
 
 from keystoneclient.middleware import auth_token
-from oslo.config import cfg
+from oslo_config import cfg
 
 
 OPT_GROUP_NAME = 'keystone_authtoken'
