@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
@@ -19,26 +18,26 @@
 """The Tuskar Service API."""
 
 import logging
-import os
 import sys
-
-from oslo.config import cfg
 from wsgiref import simple_server
 
+from oslo_config import cfg
+
 from tuskar.api import app
 from tuskar.common import service as tuskar_service
 from tuskar.openstack.common import log
 
-CONF = cfg.CONF
 
+def main(argv=None):
 
-def main():
-    # Parse config file and command line options, then start logging
-    tuskar_service.prepare_service(sys.argv)
+    if argv is None:
+        argv = sys.argv
+
+    tuskar_service.prepare_service(argv)
 
     # Build and start the WSGI app
-    host = CONF.tuskar_api_bind_ip
-    port = CONF.tuskar_api_port
+    host = cfg.CONF.tuskar_api_bind_ip
+    port = cfg.CONF.tuskar_api_port
     wsgi = simple_server.make_server(
         host, port,
         app.VersionSelectorApplication())
@@ -46,20 +45,7 @@ def main():
     LOG = log.getLogger(__name__)
     LOG.info("Serving on http://%s:%s" % (host, port))
     LOG.info("Configuration:")
-    CONF.log_opt_values(LOG, logging.INFO)
-    # make sure we have tripleo-heat-templates:
-    heat_template_path = CONF.tht_local_dir
-    try:
-        os.listdir(heat_template_path)
-    except OSError:
-        LOG.info(
-            "Can't find local tripleo-heat-template files at %s"
-            % (heat_template_path))
-        LOG.info(
-            "Cannot proceed - missing tripleo heat templates "
-            "See INSTALL documentation for more info")
-        raise
-    LOG.info("Using tripleo-heat-templates at %s" % (heat_template_path))
+    cfg.CONF.log_opt_values(LOG, logging.INFO)
 
     try:
         wsgi.serve_forever()
