@@ -15,21 +15,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_db import options as db_options
 
-from tuskar.common import paths
-from tuskar.openstack.common.db.sqlalchemy import session as db_session
-from tuskar.openstack.common import rpc
 from tuskar import version
 
-_DEFAULT_SQL_CONNECTION = 'sqlite:///' + paths.state_path_def('$sqlite_db')
-
 
 def parse_args(argv, default_config_files=None):
-    db_session.set_defaults(sql_connection=_DEFAULT_SQL_CONNECTION,
-                            sqlite_db='tuskar.sqlite')
-    rpc.set_defaults(control_exchange='tuskar')
+    db_options.set_defaults(cfg.CONF, sqlite_db='tuskar.sqlite')
+
     cfg.CONF(argv[1:],
              project='tuskar',
-             version=version.version_string(),
+             version=version.version_info.release_string(),
              default_config_files=default_config_files)
