@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
@@ -18,12 +17,14 @@ Base classes for storage engines
 """
 
 import abc
+
+from oslo_config import cfg
+from oslo_db import api as db_api
 import six
 
-from tuskar.openstack.common.db import api as db_api
-
 _BACKEND_MAPPING = {'sqlalchemy': 'tuskar.db.sqlalchemy.api'}
-IMPL = db_api.DBAPI(backend_mapping=_BACKEND_MAPPING)
+IMPL = db_api.DBAPI.from_config(cfg.CONF, backend_mapping=_BACKEND_MAPPING,
+                                lazy=True)
 
 
 def get_instance():
